# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.playback_id_api import PlaybackIDApi  # noqa: E501
from mux_python.rest import ApiException


class TestPlaybackIDApi(unittest.TestCase):
    """PlaybackIDApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.playback_id_api.PlaybackIDApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_asset_or_livestream_id(self):
        """Test case for get_asset_or_livestream_id

        Retrieve an Asset or Live Stream ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
