# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.real_time_api import RealTimeApi  # noqa: E501
from mux_python.rest import ApiException


class TestRealTimeApi(unittest.TestCase):
    """RealTimeApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.real_time_api.RealTimeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_realtime_breakdown(self):
        """Test case for get_realtime_breakdown

        Get Real-Time Breakdown  # noqa: E501
        """
        pass

    def test_get_realtime_histogram_timeseries(self):
        """Test case for get_realtime_histogram_timeseries

        Get Real-Time Histogram Timeseries  # noqa: E501
        """
        pass

    def test_get_realtime_timeseries(self):
        """Test case for get_realtime_timeseries

        Get Real-Time Timeseries  # noqa: E501
        """
        pass

    def test_list_realtime_dimensions(self):
        """Test case for list_realtime_dimensions

        List Real-Time Dimensions  # noqa: E501
        """
        pass

    def test_list_realtime_metrics(self):
        """Test case for list_realtime_metrics

        List Real-Time Metrics  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
